@@ -50,7 +50,9 @@ func isMySQL(host string, port int) (bool, error) {
 	if err != nil {
 		return false, err
 	}
-	defer conn.Close()
+	defer func() {
+         _ = conn.Close()
+       }()
 
 	plugin := &mysqlplugin.MYSQLPlugin{}
 	service, err := plugin.Run(conn, 5*time.Second, plugins.Target{Host: host})
@@ -140,7 +142,9 @@ func fingerprintMySQL(host string, port int) (MySQLInfo, error) {
 	if err != nil {
 		return info, err
 	}
-	defer conn.Close()
+	defer func() {
+         _ = conn.Close()
+       }()
 
 	plugin := &mysqlplugin.MYSQLPlugin{}
 	service, err := plugin.Run(conn, 5*time.Second, plugins.Target{Host: host})
@@ -212,7 +216,9 @@ func (c *MySQLClient) ExecuteQueryWithOpts(opts MySQLOptions, query string) (*ut
 	if err != nil {
 		return nil, err
 	}
-	defer db.Close()
+	defer func() {
+         _ = db.Close()
+       }()
 	db.SetMaxOpenConns(1)
 	db.SetMaxIdleConns(0)
 
