@@ -77,7 +77,7 @@ func New(opts Options) (*Service, error) {
 	mappingFile := filepath.Join(config.DefaultConfig.GetTemplateDir(), mappingFilename)
 	if file, err := os.Open(mappingFile); err == nil {
 		_ = yaml.NewDecoder(file).Decode(&mappingData)
-		file.Close()
+		_ = file.Close()
 	}
 	if opts.ExecuterOpts.Options.Verbose {
 		gologger.Verbose().Msgf("Normalized mapping (%d): %v\n", len(mappingData), mappingData)
@@ -206,7 +206,9 @@ func (s *Service) getTagsUsingWappalyzer(input *contextargs.MetaInput) []string
 	if err != nil {
 		return nil
 	}
-	defer resp.Body.Close()
+	defer func() {
+		_ = resp.Body.Close()
+	}()
 	data, err := io.ReadAll(io.LimitReader(resp.Body, maxDefaultBody))
 	if err != nil {
 		return nil
