@@ -2,6 +2,7 @@ package headless
 
 import (
 	"fmt"
+	"maps"
 	"net/url"
 	"strings"
 	"time"
@@ -9,7 +10,6 @@ import (
 	"github.com/projectdiscovery/retryablehttp-go"
 
 	"github.com/pkg/errors"
-	"golang.org/x/exp/maps"
 
 	"github.com/projectdiscovery/gologger"
 	"github.com/projectdiscovery/nuclei/v3/pkg/fuzz"
@@ -117,7 +117,9 @@ func (request *Request) executeRequestWithPayloads(input *contextargs.Context, p
 		request.options.Progress.IncrementFailedRequestsBy(1)
 		return errors.Wrap(err, errCouldNotGetHtmlElement)
 	}
-	defer instance.Close()
+	defer func() {
+         _ = instance.Close()
+       }()
 
 	instance.SetInteractsh(request.options.Interactsh)
 
@@ -159,9 +161,9 @@ func (request *Request) executeRequestWithPayloads(input *contextargs.Context, p
 			if act.ActionType.ActionType == engine.ActionNavigate {
 				value := act.GetArg("url")
 				if reqLog[value] != "" {
-					reqBuilder.WriteString(fmt.Sprintf("\tnavigate => %v\n", reqLog[value]))
+					_, _ = fmt.Fprintf(reqBuilder, "\tnavigate => %v\n", reqLog[value])
 				} else {
-					reqBuilder.WriteString(fmt.Sprintf("%v not found in %v\n", value, reqLog))
+					fmt.Fprintf(reqBuilder, "%v not found in %v\n", value, reqLog)
 				}
 			} else {
 				actStepStr := act.String()
@@ -189,12 +191,9 @@ func (request *Request) executeRequestWithPayloads(input *contextargs.Context, p
 	if request.options.HasTemplateCtx(input.MetaInput) {
 		outputEvent = generators.MergeMaps(outputEvent, request.options.GetTemplateCtx(input.MetaInput).GetAll())
 	}
-	for k, v := range out {
-		outputEvent[k] = v
-	}
-	for k, v := range payloads {
-		outputEvent[k] = v
-	}
+
+	maps.Copy(outputEvent, out)
+	maps.Copy(outputEvent, payloads)
 
 	var event *output.InternalWrappedEvent
 	if len(page.InteractshURLs) == 0 {
@@ -244,7 +243,7 @@ func (request *Request) executeFuzzingRule(input *contextargs.Context, payloads
 			return true
 		}
 		newInput := input.Clone()
-		newInput.MetaInput.Input = gr.Request.URL.String()
+		newInput.MetaInput.Input = gr.Request.String()
 		if err := request.executeRequestWithPayloads(newInput, gr.DynamicValues, previous, callback); err != nil {
 			return false
 		}
