@@ -131,7 +131,9 @@ func (exporter *Exporter) Export(event *output.ResultEvent) error {
 	if err != nil {
 		return err
 	}
-	defer res.Body.Close()
+	defer func() {
+         _ = res.Body.Close()
+       }()
 
 	b, err = io.ReadAll(res.Body)
 	if err != nil {
